@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package App::Cronjob;
-{
-  $App::Cronjob::VERSION = '1.200003';
-}
 # ABSTRACT: wrap up programs to be run as cron jobs
-
+$App::Cronjob::VERSION = '1.200004';
 use Digest::MD5 qw(md5_hex);
 use Errno;
 use Fcntl qw( :DEFAULT :flock );
@@ -18,6 +15,17 @@ use Sys::Hostname::Long;
 use Text::Template;
 use Time::HiRes ();
 
+#pod =head1 SEE INSTEAD
+#pod
+#pod This library, App::Cronjob, is not well documented.  Its internals may change
+#pod substantially until such point as it is documented.
+#pod
+#pod Instead of using the library, you should run the program F<cronjob> that is
+#pod installed along with the library.
+#pod
+#pod For a full description of the program's behavior, consult L<cronjob>.
+#pod
+#pod =cut
 
 my $TEMPLATE;
 
@@ -40,6 +48,8 @@ sub run {
      [ 'sender|f=s',    'sender for message',                                ],
      [ 'jobname|j=s',   'job name; used for locking, if given'               ],
      [ 'ignore-errors=s@', 'error types to ignore (like: lock)'              ],
+     [ 'temp-ignore-lock-errors=i',
+                     'failure to lock only signals an error after this long' ],
      [ 'lock!',         'lock this job (defaults to true; --no-lock for off)',
                         { default => 1 }                                     ],
   );
@@ -47,6 +57,12 @@ sub run {
   $subject = $opt->{subject} || $opt->{command};
   $subject =~ s{\A/\S+/([^/]+)(\s|$)}{$1$2} if $subject eq $opt->{command};
 
+  if (defined $opt->{temp_ignore_lock_errors}) {
+    if (grep {; $_ eq "lock" } @{$opt->{ignore_errors}}) {
+      die "--temp-ignore-lock-errors and --ignore-errors=lock are incompatible\n";
+    }
+  }
+
   $rcpts   = $opt->{rcpt}
           || [ split /\s*,\s*/, ($ENV{MAILTO} ? $ENV{MAILTO} : 'root') ];
 
@@ -83,6 +99,7 @@ sub run {
         my $stamp = scalar localtime $mtime;
         die App::Cronjob::Exception->new(
           lock => "can't lock; locked since $stamp",
+          { locked_since => $mtime },
         );
       }
 
@@ -135,6 +152,10 @@ sub run {
     unless (
       grep { $err->{type} and $_ eq $err->{type} } @{$opt->{ignore_errors}}
     ) {
+      if ($err->{type} eq "lock" && $opt->{temp_ignore_lock_errors}) {
+        my $age = time() - $err->{extra}{locked_since};
+        exit 0 if $age <= $opt->{temp_ignore_lock_errors};
+      }
       send_cronjob_report({
         is_fail => 1,
         output  => \$err->{text},
@@ -212,12 +233,10 @@ END_TEMPLATE
 
 {
   package App::Cronjob::Exception;
-{
-  $App::Cronjob::Exception::VERSION = '1.200003';
-}
-  sub new {
-    my ($class, $type, $text) = @_;
-    bless { text => $text, type => $type } => $class;
+$App::Cronjob::Exception::VERSION = '1.200004';
+sub new {
+    my ($class, $type, $text, $extra) = @_;
+    bless { type => $type, text => $text, extra => $extra } => $class;
   }
 }
 
@@ -235,7 +254,7 @@ App::Cronjob - wrap up programs to be run as cron jobs
 
 =head1 VERSION
 
-version 1.200003
+version 1.200004
 
 =head1 SEE INSTEAD
 
